@@ -3,9 +3,10 @@
 """Tests for context-dependent indentation
 """
 __version__='3.3.0'
-from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation
+from reportlab.lib.testutils import setOutDir,makeSuiteForClasses, outputfile, printLocation, invariantSeed
 setOutDir(__name__)
 import sys, os, random
+from reportlab.rl_config import invariant as rl_invariant
 from operator import truth
 import unittest
 from reportlab.pdfbase.pdfmetrics import stringWidth
@@ -23,8 +24,8 @@ from reportlab.platypus.doctemplate \
 from reportlab.platypus.tables import TableStyle, Table
 from reportlab.platypus.paragraph import *
 from reportlab.platypus.paragraph import _getFragWords
-from reportlab.platypus import FrameBG, FrameSplitter, Frame, Spacer, ShowBoundaryValue
-
+from reportlab.platypus import FrameBG, FrameSplitter, Frame, Spacer
+from reportlab.pdfgen.canvas  import ShowBoundaryValue
 
 def myMainPageFrame(canvas, doc):
     "The page frame used for all PDF documents."
@@ -63,7 +64,8 @@ class IndentTestCase(unittest.TestCase):
     "Test multi-page splitting of paragraphs (eyeball-test)."
 
     def test0(self):
-        "This makes one long multi-page paragraph."
+        "IndentTestCase test0"
+        invariantSeed(1479316371)
 
         # Build story.
         story = []
@@ -147,7 +149,7 @@ class IndentTestCase(unittest.TestCase):
         storyAdd(Paragraph("Below we split to two new frames with dark green borders",bt))
         storyAdd(FrameSplitter('templateX',['XF4','XF5'], adjustHeight=False))
         storyAdd(FrameBG(start=True,color=lightgreen,strokeColor=toColor('red'),strokeWidth=1))
-        for i in xrange(15):
+        for i in range(15):
             storyAdd(Paragraph("We should have a light green background here %d" % i,bt))
         storyAdd(Spacer(6,6))
         storyAdd(FrameBG(start=False))
